@@ -37,6 +37,7 @@ namespace CONFIG
         CONF_USE_IPV6 = 1,          // ipv6使用
         CONF_CONNECTION_NUM = 2,    // 同一ホストに対する最大コネクション数( 1 または 2 )
         CONF_USE_COOKIE_HAP = 1,    // 2chのクッキー:HAPを保存する
+        CONF_USE_OFFLAW2_2CH = 0,   // 2chの過去ログ取得時にofflaw2を使用する
         CONF_REFPOPUP_BY_MO = 0,    // レス番号の上にマウスオーバーしたときに参照ポップアップ表示する
         CONF_NAMEPOPUP_BY_MO = 0,   // 名前の上にマウスオーバーしたときにポップアップ表示する
         CONF_IDPOPUP_BY_MO = 0,     // IDの上にマウスオーバーしたときにIDをポップアップ表示する
@@ -46,7 +47,7 @@ namespace CONFIG
         CONF_TREE_SHOW_EXPANDERS = 1, // ツリービューにエクスパンダを表示
         CONF_TREE_LEVEL_INDENT = 0, // ツリービューのレベルインデント調整量(ピクセル)
         CONF_SCROLL_TREE = 1,       // カテゴリを開いたときにツリービューをスクロールする
-        CONF_SELECT_ITEM_SYNC = 1,  // ツリービューの選択を、表示中のビューと同期するか ( 0: 同期しない 1: 同期する 2: 同期する(フォルダを開く) )
+        CONF_SELECT_ITEM_SYNC = 1,  // ツリービューの選択を表示中のビューと同期する ( 0: 同期しない 1: 同期する 2: 同期する(フォルダを開く) )
         CONF_VIEW_MARGIN = 0,       // 各ビューと枠との間の余白
         CONF_LEFT_SCRBAR = 0,       // スクロールバーを左に配置
         CONF_SHOW_OLDARTICLE = 0,   // スレ一覧で古いスレも表示
@@ -104,7 +105,8 @@ namespace CONFIG
         CONF_TAB_MIN_STR = 4, // タブに表示する文字列の最小値
         CONF_SHOW_TAB_ICON = 1, // タブにアイコンを表示するか
         CONF_SWITCHTAB_WHEEL = 1, // タブ上でマウスホイールを回転してタブを切り替える
-        CONF_NEWTAB_POS = 1, // ビュー内から他のビューを開いたときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+        CONF_NEWTAB_POS = 1, // 他のビューを開くときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+        CONF_OPENTAB_POS = 0, // ツリービューで選択したビューを開くときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
         CONF_BOARDNEXTTAB_POS = 0, // 次スレ検索を開くときのタブの位置 ( 0: 次スレ検索タブ 1:新しいタブ 2:アクティブなタブを置き換え )
         CONF_SHOW_POST_MARK = 1, // スレビューに書き込みマークを表示するか
         CONF_FLAT_BUTTON = 1,    // ボタンをフラットにするか
@@ -205,7 +207,7 @@ namespace CONFIG
 #define CONF_LOGIN2CH "https://2chv.tora3.net/futen.cgi"
 
 // p2の認証サーバのアドレス
-#define CONF_LOGINP2 "http://p2.2ch.net/p2/"
+#define CONF_LOGINP2 "http://p2.2ch.sc/p2/"
 
 // BEの認証サーバのアドレス
 #define CONF_LOGINBE "http://be.2ch.net/test/login.php"
@@ -214,11 +216,11 @@ namespace CONFIG
 #define CONF_URL_BBSMENU "http://menu.2ch.net/bbsmenu.html"
 
 // スレタイ検索用メニュータイトルアドレス
-#define CONF_MENU_SEARCH_TITLE  "スレタイ検索 (find2ch)"
-#define CONF_URL_SEARCH_TITLE "http://find.2ch.net/?STR=$TEXTX&COUNT=50&TYPE=TITLE&BBS=ALL"
+#define CONF_MENU_SEARCH_TITLE  "スレタイ検索 (find.2ch.net)"
+#define CONF_URL_SEARCH_TITLE "http://find.2ch.net/search?q=$TEXTU&board=&match=full&size=50$OUTE"
 
 // スレタイ検索用正規表現
-#define CONF_REGEX_SEARCH_TITLE "<a href=\"(http[^\"]*)\">(.+?)</a> \\(([0-9]{1,4})\\)"
+#define CONF_REGEX_SEARCH_TITLE "<a [^>]*href=\"(http[^\"]*)\" class=\"title\">([^<]+)</a>"
 
 // WEB検索用メニュータイトルアドレス
 #define CONF_MENU_SEARCH_WEB  "WEB検索 (google)"
@@ -226,8 +228,8 @@ namespace CONFIG
 
 // p2 書き込み用アドレス
 
-#define CONF_URL_WRITEP2 "http://p2.2ch.net/p2/post_form.php?host=$HOST&bbs=$BBSNAME&key=$DATNAME"
-#define CONF_URL_RESP2 "http://p2.2ch.net/p2/post_form.php?host=$HOST&bbs=$BBSNAME&key=$DATNAME&popup=1&inyou=2&resnum=$NUMBER"
+#define CONF_URL_WRITEP2 "http://p2.2ch.sc/p2/post_form.php?host=$HOST&bbs=$BBSNAME&key=$DATNAME"
+#define CONF_URL_RESP2 "http://p2.2ch.sc/p2/post_form.php?host=$HOST&bbs=$BBSNAME&key=$DATNAME&popup=1&inyou=2&resnum=$NUMBER"
 
 // 2chのクッキー:HAP
 #define CONF_COOKIE_HAP ""
