@@ -17,7 +17,7 @@ using namespace DBTREE;
 
 NodeTree2chCompati::NodeTree2chCompati( const std::string& url, const std::string& date_modified )
     : NodeTreeBase( url, date_modified )
-    , m_iconv( 0 )
+    , m_iconv( NULL )
 {
 #ifdef _DEBUG
     std::cout << "NodeTree2chCompati::NodeTree2chCompati url = " << url << " modified = " << date_modified << std::endl;
@@ -83,32 +83,20 @@ char* NodeTree2chCompati::process_raw_lines( char* rawlines )
 {
     char* pos = rawlines;
 
-    if( *pos == '+' || *pos == '-' ){
+    if( *pos == '+' || *pos == '-' || *pos == 'E' ){
 
         int status = 0;
         if( pos[ 1 ] == 'O' && pos[ 2 ] == 'K' ) status = 1;
         if( pos[ 1 ] == 'E' && pos[ 2 ] == 'R' && pos[ 3 ] == 'R' ) status = 2;        
         if( pos[ 1 ] == 'I' && pos[ 2 ] == 'N' && pos[ 3 ] == 'C' && pos[ 4 ] == 'R' ) status = 3;
+        if( pos[ 0 ] == 'E' && pos[ 1 ] == 'R' && pos[ 2 ] == 'R' && pos[ 3 ] == 'O' && pos[ 4 ] == 'R' ) status = 4;
 
 #ifdef _DEBUG
         std::cout << "NodeTree2chCompati::process_raw_lines : raw mode status = " << status << std::endl;
 #endif
 
         if( status != 0 ){
-
-            // この行を飛ばす
-            char* pos_msg = pos;
-            while( *pos != '\n' && *pos != '\0' ) ++pos;
-
-            // エラー
-            if( status != 1 ){
-                int byte;
-                std::string ext_err = std::string( m_iconv->convert( pos_msg, pos - pos_msg, byte ) );
-                set_ext_err( ext_err );
-                MISC::ERRMSG( ext_err );
-            }
-
-            if( *pos == '\n' ) ++pos;
+            pos = skip_status_line( pos, status );
         }
     }
 
@@ -116,6 +104,31 @@ char* NodeTree2chCompati::process_raw_lines( char* rawlines )
 }
 
 
+//
+// ステータス行のスキップ処理
+//   status == 1 : 正常ステータス
+//   status != 1 : 異常ステータス
+// 
+char* NodeTree2chCompati::skip_status_line( char* pos, int status )
+{
+    // この行を飛ばす
+    char* pos_msg = pos;
+    while( *pos != '\n' && *pos != '\0' ) ++pos;
+
+    // エラー
+    if( status != 1 ){
+        int byte;
+        std::string ext_err = std::string( m_iconv->convert( pos_msg, pos - pos_msg, byte ) );
+        set_ext_err( ext_err );
+        MISC::ERRMSG( ext_err );
+    }
+
+    if( *pos == '\n' ) ++pos;
+
+    return pos;
+}
+
+
 //
 // raw データを dat 形式に変換
 //
